@@ -40,7 +40,7 @@ def main(argv=None, tracker=LaunchpadTracker, logging=logging):
         %prog [options]
 
         The following options must be supplied:
-        Either
+        At least one of
          --project
         or
          --projectgroup
@@ -50,6 +50,8 @@ def main(argv=None, tracker=LaunchpadTracker, logging=logging):
 
         Will process every member project of launchpad-project.
 
+        Project and projectgroup can be supplied multiple times.
+
         When run this program will ask Launchpad for OOPS references made since
         the last date it pruned up to, with an upper limit of one week from
         today. It then looks in the database for all oopses created during that
@@ -65,9 +67,9 @@ def main(argv=None, tracker=LaunchpadTracker, logging=logging):
         "Delete OOPS reports that are not referenced in a bug tracker."
     parser = optparse.OptionParser(
         description=description, usage=usage)
-    parser.add_option('--project',
+    parser.add_option('--project', action="append",
         help="Launchpad project to find references in.")
-    parser.add_option('--projectgroup',
+    parser.add_option('--projectgroup', action="append",
         help="Launchpad project group to find references in.")
     parser.add_option(
         '--lpinstance', help="Launchpad instance to use", default="production")
@@ -83,9 +85,6 @@ def main(argv=None, tracker=LaunchpadTracker, logging=logging):
             else:
                 raise ValueError(
                     'One of options %s must be supplied' % (optnames,))
-        elif len(present) != 1:
-            raise ValueError(
-                    'Only one of options %s can be supplied' % (optnames,))
     needed('project', 'projectgroup')
     logging.basicConfig(
         filename='prune.log', filemode='w', level=logging.DEBUG)
